#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_skin.interfaces.extension import IGoogleAnalyticsInfo, IUserReportInfo
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.interfaces import MANAGE_SYSTEM_PERMISSION
from pyams_utils.interfaces.site import ISiteRoot
from pyams_zmi.interfaces.menu import IPropertiesMenu
from pyams_zmi.layer import IAdminLayer

# import packages
from pyams_form.form import AJAXEditForm
from pyams_pagelet.pagelet import pagelet_config
from pyams_skin.viewlet.menu import MenuItem
from pyams_viewlet.viewlet import viewlet_config
from pyams_zmi.form import AdminDialogEditForm
from pyramid.view import view_config
from z3c.form import field

from pyams_zmi import _


#
# Google Analytics views
#

@viewlet_config(name='analytics-properties.menu', context=ISiteRoot, layer=IAdminLayer, manager=IPropertiesMenu,
                permission=MANAGE_SYSTEM_PERMISSION, weight=10)
class GoogleAnalyticsPropertiesMenuItem(MenuItem):
    """Google Analytics properties menu"""

    label = _("Google Analytics...")
    icon_class = 'fa-line-chart'
    url = 'analytics-properties.html'
    modal_target = True


@pagelet_config(name='analytics-properties.html', context=ISiteRoot, layer=IPyAMSLayer,
                permission=MANAGE_SYSTEM_PERMISSION)
class GoogleAnalyticsPropertiesEditForm(AdminDialogEditForm):
    """Google Analytics properties edit form"""

    legend = _("Update Google Analytics properties")
    ajax_handler = 'analytics-properties.json'
    edit_permission = MANAGE_SYSTEM_PERMISSION

    fields = field.Fields(IGoogleAnalyticsInfo)

    label_css_class = 'control-label col-md-4'
    input_css_class = 'col-md-8'


@view_config(name='analytics-properties.json', context=ISiteRoot, request_type=IPyAMSLayer,
             permission=MANAGE_SYSTEM_PERMISSION, renderer='json', xhr=True)
class GoogleAnalyticsPropertiesAJAXEditForm(AJAXEditForm, GoogleAnalyticsPropertiesEditForm):
    """Google Analytics properties edit form, JSON renderer"""


#
# UserReport views
#

@viewlet_config(name='user-report.menu', context=ISiteRoot, layer=IAdminLayer, manager=IPropertiesMenu,
                permission=MANAGE_SYSTEM_PERMISSION, weight=20)
class UserReportPropertiesMenuItem(MenuItem):
    """UserReport properties menu"""

    label = _("UserReport settings...")
    icon_class = 'fa-comments'
    url = 'user-report.html'
    modal_target = True


@pagelet_config(name='user-report.html', context=ISiteRoot, layer=IPyAMSLayer,
                permission=MANAGE_SYSTEM_PERMISSION)
class UserReportPropertiesEditForm(AdminDialogEditForm):
    """UserReport properties edit form"""

    legend = _("Update UserReport service properties")
    ajax_handler = 'user-report.json'
    edit_permission = MANAGE_SYSTEM_PERMISSION

    fields = field.Fields(IUserReportInfo)

    label_css_class = 'control-label col-md-4'
    input_css_class = 'col-md-8'


@view_config(name='user-report.json', context=ISiteRoot, request_type=IPyAMSLayer,
             permission=MANAGE_SYSTEM_PERMISSION, renderer='json', xhr=True)
class UserReportPropertiesAJAXEditForm(AJAXEditForm, UserReportPropertiesEditForm):
    """UserReport properties edit form, JSON renderer"""
